@@ -743,7 +743,10 @@ def _render_scenario(
         name = element.attrib["name"]
         readable = name.replace("_", " ")
 
-        element.tag = "span"
+        # Assume that paragraphs are rendered as <p> from markdown to html.
+        contains_paragraph = False if next(element.iter("p"), None) is None else True
+
+        element.tag = "span" if not contains_paragraph else "div"
         element.attrib = {"class": "phase", "data-text": name}
 
         element.append(_new_element(tag="sup", text=readable))
@@ -768,7 +771,10 @@ def _render_scenario(
     for element in root.iter("level"):
         name = element.attrib["name"]
 
-        element.tag = "span"
+        # Assume that paragraphs are rendered as <p> from markdown to html.
+        contains_paragraph = False if next(element.iter("p"), None) is None else True
+
+        element.tag = "span" if not contains_paragraph else "div"
         element.attrib = {"class": "level", "data-text": name}
 
         element.append(_new_element(tag="sup", text=name.replace("_", " ")))
@@ -974,11 +980,11 @@ def _render_scenario(
                     display: inline-block;
                 }
         
-                span.phase {
+                span.phase, div.phase {
                     background-color: #eefbfb;
                 }
         
-                span.level {
+                span.level, div.level {
                     background-color: #eefbee;
                 }
         
@@ -1006,7 +1012,7 @@ def _render_scenario(
             assert relation.source == scenario.identifier
 
             li = ET.Element("li")
-            li.append(_new_element("span", f"{scenario.title} {relation.nature} "))
+            li.append(_new_element("span", f"{scenario.title} → {relation.nature} → "))
 
             target = ontology.scenario_map[relation.target]
 
@@ -1024,9 +1030,7 @@ def _render_scenario(
 
         ul.tail = "\n"
         main_div.insert(0, ul)
-        main_div.insert(
-            0, _new_element(tag="h2", text="Relations from Other Scenarios")
-        )
+        main_div.insert(0, _new_element(tag="h2", text="Relations to Other Scenarios"))
 
     if len(relations_to) > 0:
         ul = ET.Element("ul")
@@ -1045,12 +1049,14 @@ def _render_scenario(
 
             li = ET.Element("li")
             li.append(_new_element("a", text=source.title, attrib={"href": source_url}))
-            li.append(_new_element("span", f" {relation.nature} {scenario.title}"))
+            li.append(_new_element("span", f" ← {relation.nature} ← {scenario.title}"))
 
             ul.append(li)
 
         main_div.insert(0, ul)
-        main_div.insert(0, _new_element(tag="h2", text="Relations to Other Scenarios"))
+        main_div.insert(
+            0, _new_element(tag="h2", text="Relations from Other Scenarios")
+        )
 
     ##
     # Insert volumetric plot
